experimental_module
===================

Functionality that is subject to breaking changes without notice.
Use at your own risk.

This module exposes :badge:`stability:experimental` helpers for advanced use cases.

.. py:function:: experimental_feature(data)

   Process *data* using an unstable algorithm.

   .. badges:: stability:experimental area:utils

   :param data: Input data.
   :raises NotImplementedError: Until the feature is finalised.
